==> opennms-dao-api-19.0.0-20161115.161250-298-sources.jar: org/opennms/netmgt/dao/api/InterfaceToNodeCache.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2003-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.api;

import java.net.InetAddress;

public interface InterfaceToNodeCache {

	void dataSourceSync();

	int getNodeId(String location, InetAddress ipAddr);

	int setNodeId(String location, InetAddress ipAddr, int nodeId);

	int removeNodeId(String location, InetAddress ipAddr);

	int size();

	/**
	 * Should only be used for testing.
	 */
	void clear();
}

==> opennms-dao-api-21.1.0-20200616.092453-152-sources.jar: org/opennms/netmgt/dao/api/InterfaceToNodeCache.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2003-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.api;

import java.net.InetAddress;
import java.util.Iterator;
import java.util.Optional;

public interface InterfaceToNodeCache {

	void dataSourceSync();

	Iterable<Integer> getNodeId(String location, InetAddress ipAddr);

	boolean setNodeId(String location, InetAddress ipAddr, int nodeId);

	boolean removeNodeId(String location, InetAddress ipAddr, int nodeId);

	int size();

	/**
	 * Should only be used for testing.
	 */
	void clear();

	default Optional<Integer> getFirstNodeId(String location, InetAddress ipAddr) {
		final Iterator<Integer> it = this.getNodeId(location, ipAddr).iterator();
		if (it.hasNext()) {
			return Optional.of(it.next());
		} else {
			return Optional.empty();
		}
	}
}
